@@ -1,6 +1,14 @@
 from copy import deepcopy
 from dataclasses import dataclass, fields, MISSING
-from typing import Any, Dict, Optional, Union, Tuple
+from typing import Any, Dict, Optional, Union, get_args, get_origin
+
+try:
+    # Python >= 3.10
+    from types import UnionType
+
+    UNION_TYPES = (UnionType, Union)
+except ImportError:
+    UNION_TYPES = (Union,)  # type: ignore
 
 
 @dataclass
@@ -46,10 +54,10 @@ class BaseConfig:
 
 
 def unwrap_optional_type(T: type) -> type:
-    opt_types: Tuple[type, ...] = getattr(T, "__args__", ())
-    if not isinstance(None, opt_types) or getattr(T, "__origin__", None) is not Union:
+    opt_types = get_args(T)
+    if not isinstance(None, opt_types) or get_origin(T) not in UNION_TYPES:
         return T
-    return opt_types[0]
+    return next(t for t in opt_types if t is not type(None))
 
 
 @dataclass
