@@ -18,3 +18,9 @@ class ConflictError(APIException):
     status_code = status.HTTP_409_CONFLICT
     default_detail = "Request conflict with current state of the target resource."
     default_code = "conflict"
+
+
+class UnprocessableEntityError(APIException):
+    status_code = status.HTTP_422_UNPROCESSABLE_ENTITY
+    default_detail = "Target resource could NOT be updated with request body."
+    default_code = "unprocessable_entity"
