@@ -26,7 +26,7 @@ def NameField(**kwargs):
     )
 
 
-def CodeField(lower=True, **kwargs):
+def CodeField(lower: bool = True, **kwargs):
     unique = kwargs.pop("unique", True)
     char_set = "a-z" if lower else "A-Z"
     return models.CharField(
