@@ -1,8 +1,9 @@
 from typing import Any, Dict, List, Type
+
 from django.contrib.auth.models import AbstractUser
 from django.db import models
-from rest_framework.serializers import Serializer, ValidationError
 from rest_framework import serializers
+from rest_framework.serializers import Serializer, ValidationError
 
 
 def get_request_username(serializer: Serializer) -> AbstractUser:
@@ -14,6 +15,12 @@ class DetailedValidationError(ValidationError):
         super().__init__({field: detail}, code="invalid")
 
 
+class DetailedValidationErrorInfo(DetailedValidationError):
+    """An expected `DetailedValidationError` which should NOT trigger an error,
+    rather an info.
+    """
+
+
 # TODO DRF contribution
 def update_related_fields(
     instance: models.Model,
