@@ -11,7 +11,7 @@ class LogView(viewsets.ViewSet):
 
     permission_classes = (permissions.IsAuthenticated,)
 
-    def create(self, request):  # pylint: disable=no-self-use
+    def create(self, request):
         forward_headers = ("User-Agent", "Accept-Language", "Origin", "Referer")
         headers = {name: request.headers.get(name) for name in forward_headers}
         payload = request.data.copy()
