@@ -1,6 +1,6 @@
 from typing import Collection, Type
 
-from rest_framework import response, status
+from rest_framework import response, serializers, status
 from rest_framework.permissions import BasePermission
 from rest_framework.schemas.openapi import AutoSchema
 from rest_framework.decorators import action
@@ -17,9 +17,7 @@ def get_model(serializer):
 
 
 def get_fields(model):
-    # pylint: disable=protected-access
-    return model._meta.fields
-    # pylint: enable=protected-access
+    return model._meta.fields  # pylint: disable=protected-access
 
 
 class UniqueSchema(AutoSchema):
@@ -29,21 +27,23 @@ class UniqueSchema(AutoSchema):
             status.HTTP_409_CONFLICT: {"description": "is NOT unique"},
         }
 
-    def get_request_body(self, path, method):
-        properties = {}
-        for field in get_fields(get_model(self.get_serializer(path, method))):
-            if field.unique:
-                properties[field.name] = {"type": "string", "required": False}
+    def get_component_name(self, serializer):
+        return f"Unique{super().get_component_name(serializer)}"
 
+    def get_components(self, path, method):
+        serializer = self.get_serializer(path, method)
+        if not isinstance(serializer, serializers.Serializer):
+            return {}
+        content = self.map_serializer(serializer)
+        properties = {
+            field.name: content["properties"][field.name]
+            for field in get_fields(get_model(serializer))
+            if field.unique
+        }
         return {
-            "content": {
-                "application/json": {
-                    "schema": {
-                        "type": "object",
-                        "title": f"Unique{self.get_operation_id_base(path, method, 'unique')}",
-                        "properties": properties,
-                    }
-                }
+            self.get_component_name(serializer): {
+                "type": content["type"],
+                "properties": properties,
             }
         }
 
